The set of valid values for FTP commands
Structs
- Line
Linecontains a command code and the contents of a line of text read from the network.
Enums
- File
Type - File Type used in
TYPEcommand - Format
Control - Text Format Control used in
TYPEcommand - FtpError
FtpErroris a library-global error type to describe the different kinds of errors that might occur while using FTP.
Type Aliases
- Result
- A shorthand for a Result whose error type is always an FtpError.